@@ -187,7 +187,11 @@ class ErrorDisplay(object):
 
 class QHtmlDelegate(QtGui.QStyledItemDelegate):
 
-	# @bug Not showing all of a message
+	UNDEFINED_SIZE = -1
+
+	def __init__(self, *args, **kwd):
+		QtGui.QStyledItemDelegate.__init__(*((self, ) + args), **kwd)
+		self._width = self.UNDEFINED_SIZE
 
 	def paint(self, painter, option, index):
 		newOption = QtGui.QStyleOptionViewItemV4(option)
@@ -229,13 +233,21 @@ class QHtmlDelegate(QtGui.QStyledItemDelegate):
 		doc.documentLayout().draw(painter, ctx)
 		painter.restore()
 
+	def setWidth(self, width):
+		# @bug we need to be emitting sizeHintChanged but it requires an index
+		self._width = width
+
 	def sizeHint(self, option, index):
 		newOption = QtGui.QStyleOptionViewItemV4(option)
 		self.initStyleOption(newOption, index)
 
 		doc = QtGui.QTextDocument()
 		doc.setHtml(newOption.text)
-		doc.setTextWidth(newOption.rect.width())
+		if self._width != self.UNDEFINED_SIZE:
+			width = self._width
+		else:
+			width = newOption.rect.width()
+		doc.setTextWidth(width)
 		size = QtCore.QSize(doc.idealWidth(), doc.size().height())
 		return size
 
@@ -260,7 +272,7 @@ def _null_set_autorient(window, isStackable):
 
 
 def _maemo_set_autorient(window, isStackable):
-	window.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow, isStackable)
+	window.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, isStackable)
 
 
 try:
@@ -270,34 +282,35 @@ except AttributeError:
 	set_autorient = _null_set_autorient
 
 
-def _null_set_landscape(window, isStackable):
+def screen_orientation():
+	geom = QtGui.QApplication.desktop().screenGeometry()
+	if geom.width() <= geom.height():
+		return QtCore.Qt.Vertical
+	else:
+		return QtCore.Qt.Horizontal
+
+
+def _null_set_window_orientation(window, orientation):
 	pass
 
 
-def _maemo_set_landscape(window, isStackable):
-	window.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow, isStackable)
+def _maemo_set_window_orientation(window, orientation):
+	if orientation == QtCore.Qt.Vertical:
+		newHint = QtCore.Qt.WA_Maemo5LandscapeOrientation
+		oldHint = QtCore.Qt.WA_Maemo5PortraitOrientation
+	elif orientation == QtCore.Qt.Horizontal:
+		oldHint = QtCore.Qt.WA_Maemo5LandscapeOrientation
+		newHint = QtCore.Qt.WA_Maemo5PortraitOrientation
+	window.setAttribute(oldHint, False)
+	window.setAttribute(newHint, True)
 
 
 try:
 	QtCore.Qt.WA_Maemo5LandscapeOrientation
-	set_landscape = _maemo_set_landscape
-except AttributeError:
-	set_landscape = _null_set_landscape
-
-
-def _null_set_portrait(window, isStackable):
-	pass
-
-
-def _maemo_set_portrait(window, isStackable):
-	window.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow, isStackable)
-
-
-try:
 	QtCore.Qt.WA_Maemo5PortraitOrientation
-	set_portrait = _maemo_set_portrait
+	set_window_orientation = _maemo_set_window_orientation
 except AttributeError:
-	set_portrait = _null_set_portrait
+	set_window_orientation = _null_set_window_orientation
 
 
 def _null_show_progress_indicator(window, isStackable):
@@ -305,7 +318,7 @@ def _null_show_progress_indicator(window, isStackable):
 
 
 def _maemo_show_progress_indicator(window, isStackable):
-	window.setAttribute(QtCore.Qt.WA_Maemo5StackedWindow, isStackable)
+	window.setAttribute(QtCore.Qt.WA_Maemo5ShowProgressIndicator, isStackable)
 
 
 try:
@@ -330,14 +343,6 @@ except AttributeError:
 	mark_numbers_preferred = _null_mark_numbers_preferred
 
 
-def screen_orientation():
-	geom = QtGui.QApplication.desktop().screenGeometry()
-	if geom.width() <= geom.height():
-		return QtCore.Qt.Vertical
-	else:
-		return QtCore.Qt.Horizontal
-
-
 def _null_get_theme_icon(iconNames, fallback = None):
 	icon = fallback if fallback is not None else QtGui.QIcon()
 	return icon
